#include <iostream>
#include <iomanip>
#include <sstream>
#include <vector>

#include "TROOT.h"
#include "TFile.h"
#include "TRandom3.h" 

#include "CRootManager.hh"
#include "CDataSample.hh"

static const Int_t N = 10000;

int main()
{
  gROOT->ProcessLine("#include <vector>");

  TRandom3* random = new TRandom3;
  random->SetSeed();

  CRootManager* rootmanager = new CRootManager;
  CDataSample* data = new CDataSample;

  for(int runnumber = 0; runnumber < 10; ++runnumber){
    std::cout << "run:" << runnumber << std::endl;

    rootmanager->Reset();

    std::ostringstream oss;
    oss << "root/run" << std::setw(4) << std::setfill('0') << runnumber << ".root";
    rootmanager->CreateFile(oss.str().c_str(), "recreate");
    rootmanager->CreateTree("Koyomi", "Koyomi is Hero of Bakemono-Gatari");
    rootmanager->CreateBranch("branchname", &data);

    for(Int_t i = 0; i < N; ++i){
      double x,y,z;
      double r = random->Rndm();
      random->Sphere(x,y,z,r);

      data->Reset();

      data->eventflag = random->Integer(2);
      data->x = x;
      data->y = y;
      data->z = z;      
      data->r = r;
      data->vd.push_back(x);
      data->vd.push_back(y);
      data->vd.push_back(z);

      rootmanager->Fill();
    }
    rootmanager->Write();
  }

  delete random;
  delete data;
  delete rootmanager;

  return 0;
}
